magneticalc.Perspective_Widget.Perspective_Widget

# ``magneticalc`.`Perspective_Widget`.`Perspective_Widget``

class documentation

`class Perspective_Widget(QGroupBox2):`

Constructor: `Perspective_Widget(gui)`

View In Hierarchy

Perspective_Widget class.

Method | `__init__` | Populates the widget.
Method | `reload` | Reloads the widget.
Method | `set_perspective` | Sets display perspective.
Instance Variable | `gui` | Undocumented

Inherited from `QGroupBox2`:

Method | `set_color` | Sets the style and label color of the groupbox.

Inherited from `QLayouted` (via `QGroupBox2`):

Method | `addButtons` | Adds buttons.
Method | `addLayout` | Adds layout.
Method | `addSpacing` | Adds spacing.
Method | `addWidget` | Adds widget.
Method | `install_layout` | Installs this layout in the parent.
Instance Variable | `_layout` | Undocumented

def __init__(self, gui: `GUI`):
overrides `magneticalc.QtWidgets2.QGroupBox2.QGroupBox2.__init__`

Populates the widget.

Parameters
gui: `GUI` | GUI

def reload(self):

Reloads the widget.

def set_perspective(self, preset: `dict`):

Sets display perspective.

Parameters
preset: `dict` | Perspective preset (parameters, see VisPyCanvas module)

gui =

Undocumented